/******************************************************************************
 * Example code which tests BBox's graphic glitch when window is enlarged bug.
 * AGMS20170323  Compile with:
 * g++ -Wall -Wno-multichar -g -lbe BBoxGraphicsGlitch.cpp
 * And use ProcessController to quit (window close not implemented).
 */

#include <Application.h>
#include <Box.h>
#include <Window.h>

class BBoxWindow : public BWindow
{
public:
  BBoxWindow (BRect FrameRect);

public:
  virtual void FrameResized (float newWidth, float newHeight);
  virtual bool QuitRequested ();
};

BBoxWindow::BBoxWindow (BRect FrameRect)
: BWindow (FrameRect, "BBox Glitch Test - Resize diagonally to see it",
    B_DOCUMENT_WINDOW, 0)
{
}

void BBoxWindow::FrameResized (float newWidth, float newHeight)
{
  BWindow::FrameResized (newWidth, newHeight);
  snooze (100000); // Simulate a slow computer.
}

bool BBoxWindow::QuitRequested ()
{
  be_app->PostMessage (B_QUIT_REQUESTED);
  return true;
}


class BBoxGlitchApp : public BApplication
{
public:
  BBoxGlitchApp ();

  virtual void ReadyToRun ();
};

BBoxGlitchApp::BBoxGlitchApp ()
: BApplication ("application/BBoxGlitch")
{
}

void BBoxGlitchApp::ReadyToRun ()
{
  BWindow *WindowPntr = new BBoxWindow (BRect (40, 40, 200, 800));
  WindowPntr->Show ();

  BRect BoxRect (WindowPntr->Bounds());
  BoxRect.InsetBy (15, 15);
  BBox *BBoxPntr = new BBox (BoxRect, "BBox with a Glitch",
    B_FOLLOW_LEFT_RIGHT);
  WindowPntr->AddChild (BBoxPntr);

  WindowPntr->Lock ();
  BBoxPntr->SetViewColor (make_color (50, 150, 250, 255));
  BBoxPntr->Invalidate ();
  WindowPntr->Unlock ();
}


int main (int argc, char **argv)
{
  BBoxGlitchApp MyApp;

  if (MyApp.InitCheck () == B_OK)
    MyApp.Run ();

 return 0;
}
